@@ -66,7 +66,7 @@ void CmdLine::keyRelease(GtkWidget* _W, GdkEventKey* _E, CmdLine* _C)
 char* CmdLine::getStr()         { return(gtk_entry_get_text(GTK_ENTRY(E))); }
 void  CmdLine::setStr()
 {
-  char buf[BUFSIZ],* s = Util::path("/", 0, 0);
+  char buf[BUFSIZ],* s = Util::path(NULL, NULL, "/", 0, 0);
   sprintf(buf, "/%s/", s);
   
   gtk_entry_set_text(GTK_ENTRY(E), buf);
