@@ -16,9 +16,9 @@ class Image : public TshWgt
 {
 private:
   bool       M;     // Mode: true.root window false.canvas
-  GtkWidget* W[2];  // 0.FullScreen 1.Image
+  GtkWidget* W[3];  // 0.FullScreen 1.Image 2.Drawing_Area
   GdkImlibImage* I; // Imlib Image
-  GdkPixmap* P;     // Pixmap
+  static GdkPixmap* P;     // Pixmap
   GdkBitmap* B;     // Mask
   Pop*       Pm;    // Pop Menu
   int X,Y;          // X.Width, Y.Height
@@ -38,6 +38,9 @@ public:
   void setMode(bool);
   void hideRoot();
   static void press(GtkWidget*, GdkEventButton*, Image*);
+  static void motion(GtkWidget*, GdkEventMotion*, Image*);
+  static gint expose(GtkWidget*, GdkEventExpose*, Image*);
+  static void draw(GtkWidget*, gdouble, gdouble);
   void popUp(GdkEventButton*);
   void newPop();
 };
